==> sisu_7.1.7.orig.tar.xz: sisu-7.1.7/lib/sisu/txt_output.rb <==
# encoding: utf-8
=begin

* Name: SiSU

** Description: documents, structuring, processing, publishing, search
*** plaintext

** Author: Ralph Amissah
  <ralph@amissah.com>
  <ralph.amissah@gmail.com>

** Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015 Ralph Amissah,
  All Rights Reserved.

** License: GPL 3 or later:

  SiSU, a framework for document structuring, publishing and search

  Copyright (C) Ralph Amissah

  This program is free software: you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the Free
  Software Foundation, either version 3 of the License, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along with
  this program. If not, see <http://www.gnu.org/licenses/>.

  If you have Internet connection, the latest version of the GPL should be
  available at these locations:
  <http://www.fsf.org/licensing/licenses/gpl.html>
  <http://www.gnu.org/licenses/gpl.html>

  <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>

** SiSU uses:
  * Standard SiSU markup syntax,
  * Standard SiSU meta-markup syntax, and the
  * Standard SiSU object citation numbering and system

** Hompages:
  <http://www.jus.uio.no/sisu>
  <http://www.sisudoc.org>

** Git
  <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
  <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/txt_output.rb;hb=HEAD>

=end
module Txt_Output
  class Output
    include SiSU_Param
    include SiSU_Env
    def document(content,outputfile)
      emptyline=0
      content.each do |para|           # this is a hack
        if para.is_a?(Array) \
        and para.length > 0
          para.each do |line|
            if line
              line=line.gsub(/[ \t]+$/m,'').
                gsub(/^\A[ ]*\Z/m,'')
              (line=~/^\A\Z/) \
              ? (emptyline+=1)
              : emptyline=0
              if emptyline < 2         #remove additional empty lines
                outputfile.puts line
              end
            end
          end
        else outputfile.puts para      #unix plaintext # /^([*=-]|\.){5}/
        end
      end
      outputfile.close
    end
  end
end
__END__

==> sisu_7.1.9.orig.tar.xz: sisu-7.1.9/lib/sisu/txt_output.rb <==
# encoding: utf-8
=begin

* Name: SiSU

** Description: documents, structuring, processing, publishing, search
*** plaintext

** Author: Ralph Amissah
  [ralph@amissah.com]
  [ralph.amissah@gmail.com]

** Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Ralph Amissah,
  All Rights Reserved.

** License: GPL 3 or later:

  SiSU, a framework for document structuring, publishing and search

  Copyright (C) Ralph Amissah

  This program is free software: you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the Free
  Software Foundation, either version 3 of the License, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along with
  this program. If not, see [http://www.gnu.org/licenses/].

  If you have Internet connection, the latest version of the GPL should be
  available at these locations:
  [http://www.fsf.org/licensing/licenses/gpl.html]
  [http://www.gnu.org/licenses/gpl.html]

** SiSU uses:
  * Standard SiSU markup syntax,
  * Standard SiSU meta-markup syntax, and the
  * Standard SiSU object citation numbering and system

** Hompages:
  [http://www.jus.uio.no/sisu]
  [http://www.sisudoc.org]

** Git
  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary]
  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/txt_output.rb;hb=HEAD]

=end
module Txt_Output
  class Output
    include SiSU_Param
    include SiSU_Env
    def document(content,outputfile)
      emptyline=0
      content.each do |para|           # this is a hack
        if para.is_a?(Array) \
        and para.length > 0
          para.each do |line|
            if line
              line=line.gsub(/[ \t]+$/m,'').
                gsub(/^\A[ ]*\Z/m,'')
              (line=~/^\A\Z/) \
              ? (emptyline+=1)
              : emptyline=0
              if emptyline < 2         #remove additional empty lines
                outputfile.puts line
              end
            end
          end
        else outputfile.puts para      #unix plaintext # /^([*=-]|\.){5}/
        end
      end
      outputfile.close
    end
  end
end
__END__
